@@ -139,25 +139,101 @@ a block quote
     expected = doc(para("Code: <code>text</code>"))
     assert_equal expected, doc
 
+    doc = parse "Code: ` text`"
+    expected = doc(para("Code: <code> text</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: `text `"
+    expected = doc(para("Code: <code>text </code>"))
+    assert_equal expected, doc
+
     doc = parse "Code: ` text `"
     expected = doc(para("Code: <code>text</code>"))
     assert_equal expected, doc
 
+    doc = parse "Code: ` text\t`"
+    expected = doc(para("Code: <code> text\t</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: `\ttext `"
+    expected = doc(para("Code: <code>\ttext </code>"))
+    assert_equal expected, doc
+
     doc = parse "Code: ``text`s``"
     expected = doc(para("Code: <code>text`s</code>"))
     assert_equal expected, doc
 
+    doc = parse "Code: `` text`s``"
+    expected = doc(para("Code: <code> text`s</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: ``text`s ``"
+    expected = doc(para("Code: <code>text`s </code>"))
+    assert_equal expected, doc
+
     doc = parse "Code: `` text`s ``"
     expected = doc(para("Code: <code>text`s</code>"))
     assert_equal expected, doc
 
+    doc = parse "Code: `` text`s\t``"
+    expected = doc(para("Code: <code> text`s\t</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: ``\ttext`s ``"
+    expected = doc(para("Code: <code>\ttext`s </code>"))
+    assert_equal expected, doc
+
     doc = parse "Code: ```text`s```"
     expected = doc(para("Code: <code>text`s</code>"))
     assert_equal expected, doc
 
+    doc = parse "Code: ``` text`s```"
+    expected = doc(para("Code: <code> text`s</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: ```text`s ```"
+    expected = doc(para("Code: <code>text`s </code>"))
+    assert_equal expected, doc
+
     doc = parse "Code: ``` text`s ```"
     expected = doc(para("Code: <code>text`s</code>"))
     assert_equal expected, doc
+
+    doc = parse "Code: ``` text`s\t```"
+    expected = doc(para("Code: <code> text`s\t</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: ```\ttext`s ```"
+    expected = doc(para("Code: <code>\ttext`s </code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: `\\`"
+    expected = doc(para("Code: <code>\\\\</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: ` \\ `"
+    expected = doc(para("Code: <code>\\\\</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: `\\`s`"
+    expected = doc(para("Code: <code>\\\\</code>s`"))
+    assert_equal expected, doc
+
+    doc = parse "Code: ``\\`s``"
+    expected = doc(para("Code: <code>\\`s</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: `` \\`s ``"
+    expected = doc(para("Code: <code>\\`s</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: ```\\`s```"
+    expected = doc(para("Code: <code>\\`s</code>"))
+    assert_equal expected, doc
+
+    doc = parse "Code: ``` \\`s ```"
+    expected = doc(para("Code: <code>\\`s</code>"))
+    assert_equal expected, doc
   end
 
   def test_parse_code_github
@@ -195,7 +271,7 @@ code goes here
     doc = <<-MD
 Example:
 
-``` ruby
+```ruby
 code goes here
 ```
     MD
@@ -1157,6 +1233,56 @@ and an extra note.[^2]
     assert_equal expected, doc
   end
 
+  def test_gfm_table_with_backslashes_in_code_spans
+    doc = parse <<~MD
+    Plain text: `$\\\\` and `$\\\\ ` should work.
+
+    | Context | Code | Expected |
+    |---------|------|----------|
+    | Plain   | `$\\\\` | Should show backslash |
+    | Escaped | `$\\\\ ` | Should show backslash |
+    | Multiple| `\\\\n\\\\t` | Should show backslashes |
+    MD
+
+    head = %w[Context Code Expected]
+    align = [nil, nil, nil]
+
+    body = [
+      ['Plain', '<code>$\\\\</code>', 'Should show backslash'],
+      ['Escaped', '<code>$\\\\ </code>', 'Should show backslash'],
+      ['Multiple', '<code>\\\\n\\\\t</code>', 'Should show backslashes'],
+    ]
+
+    expected_table = @RM::Table.new(head, align, body)
+
+    expected = doc(
+      para('Plain text: <code>$\\\\</code> and <code>$\\\\ </code> should work.'),
+      expected_table
+    )
+
+    assert_equal expected, doc
+  end
+
+  def test_markdown_link_with_styled_label
+    markdown = <<~MD
+      [Link to Foo](https://example.com)
+
+      [Link to `Foo`](https://example.com)
+
+      [Link to **Foo**](https://example.com)
+
+      [Link to `Foo` and `\Bar` and `Baz`](https://example.com)
+    MD
+
+    doc = parse markdown
+    html = @to_html.convert doc
+
+    assert_includes html, '<a href="https://example.com">Link to Foo</a>'
+    assert_includes html, '<a href="https://example.com">Link to <code>Foo</code></a>'
+    assert_includes html, '<a href="https://example.com">Link to <strong>Foo</strong></a>'
+    assert_includes html, '<a href="https://example.com">Link to <code>Foo</code> and <code>Bar</code> and <code>Baz</code></a>'
+  end
+
   def parse(text)
     @parser.parse text
   end
